PREFIX=$1
SUMLOG=${PREFIX}.P1.sumlog
OUTFILE=${PREFIX}.bashmerge.P1.empp

if [ ! -e $SUMLOG ]; then 
	echo "File $SUMLOG does not exist."
	exit
fi

if (( `dir -o ${PREFIX}.*.P1.perm 2> /dev/null | wc -l` == 0 )); then 
	echo "Did not find any .P1.perm files with prefix ${PREFIX}"
	exit
fi

SUMMFILE=.tmp1_$RANDOM
for FILE in ${PREFIX}.*.P1.perm; do
	if [ ! -e $SUMMFILE ]; then
		head -1 $FILE | awk 'BEGIN{OFS="\t"} {$NF="no.perm"; print $0}' > $SUMMFILE
	fi

	awk 	'NR <= 6	{next}
		 NR == FNR	{stat[$1] = $4; next}
		 FNR == 1	{ 
				  for (i=1; i < NF; i++) {
					if (!($i in stat)) exit 13;
					statloc[i] = stat[$i];
					count[i] = 0;
				  }
				  nperm = 0;
				  next;
				}
		 		{ 
				  for (i=1; i < NF; i++) {if ($i > statloc[i]) count[i]++}
				  nperm++;
				}
		 END		{ 
				  for (i=1; i < NF; i++) printf "%s\t", count[i];
				  print nperm;
				}' $SUMLOG $FILE >> $SUMMFILE

	if (( $? == 13 )); then 
		echo "Error: Gene-set IDs in .sumlog file do not match IDs in .perm file $FILE"
		rm $SUMMFILE
		exit
	fi
done



awk	'BEGIN			{OFS="\t"; print "Geneset", "no.genes", "no.snps", "no.perm", "stat", "emp_p"}
	 NR == 1		{
				  for (i=1; i < NF; i++) {
					statname[i] = $i;
					count[$i] = 0;
				  }
				  nperm = 0;
				  next
				}
	 NR == FNR		{
				  for (i=1; i < NF; i++) {count[statname[i]] += $i}
				  nperm += $NF;
				  next
				}
	 FNR <= 6		{next}
	 !($1 in count)	{exit 13}
				{print $1, $3, $2, nperm, $4, count[$1]/nperm}' $SUMMFILE $SUMLOG > $OUTFILE
	 
if (( $? == 13 )); then 
	echo "Error: Gene-set IDs in .sumlog file do not match IDs in .perm file"
	rm $OUTFILE
fi

rm $SUMMFILE






