DATFILE=$1
PVALFILE=$2
MAPFILE=$3
OUTNAME=$4


if [[ ! -e ${DATFILE}.bed || ! -e ${DATFILE}.bim || ! -e ${DATFILE}.fam ]]; then 
	echo "Cannot find all PLINK data files with prefix ${DATFILE}."
	exit
fi

if [[ ! -e $PVALFILE ]]; then
	echo "File $PVALFILE does not exist."
	exit
fi

if [[ ! -e $MAPFILE ]]; then
	echo "File $MAPFILE does not exist."
	exit
fi

if [[ "$OUTNAME" == "" ]]; then 
	echo "Output file prefix (3rd argument) not specified."	
	exit
fi

#create file with rs-id in first column, p-value in second column; invalid p-values are removed
TMP1=.tmp1_$RANDOM
awk	'NR == 1 				{ for (i=1; i<=NF; i++) {
							if (tolower($i) == "snp") snpfield=i;
							if (tolower($i) == "p") pfield=i;
						  }
						  if (!(snpfield > 0 && pfield > 0)) exit 13  
						}
	$pfield >= 0 && $pfield <= 1	{ print $snpfield, $pfield }' $PVALFILE > $TMP1

if (( "$?" == 13 )); then 
	echo "Cannot find SNP and/or P column in file ${PVALFILE}"
	exit
fi

#Check for p=0
P0=`awk '$2 == 0' $TMP1 | wc -l`
if ((P0 == 0)); then P0=no; fi
echo "Detected $P0 p-values of 0 in file ${PVALFILE}."
if [[ "$P0" != "no" ]]; then exit; fi

#create stat file
TMP2=.tmp2_$RANDOM
awk 	'NR==FNR 	{arr[$2]; next} 
	 $1 in arr	{print $0}'		 ${DATFILE}.bim $PVALFILE > $TMP2
echo "cluster stat" > ${OUTNAME}.stat
awk 	'NR==FNR 	{if ($2 > 0 && $2 <= 1) {logp[$1] = -log($2)/log(10)}; next} 
	 $1 in logp 	{stat[$3] += logp[$1]} 
	 END		{for (i in stat) {print i, stat[i]}}' $TMP2 $MAPFILE >> ${OUTNAME}.stat

#create PLINK file with only SNPs in .pval file
plink --bfile $DATFILE --extract $TMP1 --make-bed --out $OUTNAME

#Put 50:50 case-control phenotype in .fam file
awk '{$6 = 1+(NR%2); print $0}' ${OUTNAME}.fam > $TMP2
mv $TMP2 ${OUTNAME}.fam

rm $TMP1


