DATFILE=$1
PVALFILE=$2
MAPFILE=$3
OUTNAME=$4

if [[ ! -e $PVALFILE ]]; then
	echo "File $PVALFILE does not exist."
	exit
fi

if [[ ! -e $MAPFILE ]]; then
	echo "File $MAPFILE does not exist."
	exit
fi

if [[ "$OUTNAME" == "" ]]; then 
	echo "Output file prefix (3rd argument) not specified."	
	exit
fi


#create file with rs-id in first column, p-value in second column
TMP1=.tmp1_$RANDOM
awk	'NR == 1 				{ for (i=1; i<=NF; i++) {
							if (tolower($i) == "snp") snpfield=i;
							if (tolower($i) == "p") pfield=i;
						  }
						  if (!(snpfield > 0 && pfield > 0)) exit 13  
						}
	$pfield >= 0 && $pfield <= 1	{ print $snpfield, $pfield }' $PVALFILE > $TMP1

if (( "$?" == 13 )); then 
	echo "Cannot find SNP and/or P column in file ${PVALFILE}"
	exit
fi

#Check for p=0
P0=`awk '$2 == 0' $TMP1 | wc -l`
if ((P0 == 0)); then P0=no; fi
echo "Detected $P0 p-values of 0 in file ${PVALFILE}."
if [[ "$P0" != "no" ]]; then exit; fi

#create merged 1000 genomes PLINK file
TMP2=.tmp2_$RANDOM
for CHR in {1..22} X; do 
	echo "Processing chromosome ${CHR}..."
	DATNAME=${DATFILE}_chr$CHR
	if [[ ! -e ${DATNAME}.bed || ! -e ${DATNAME}.bim || ! -e ${DATNAME}.fam ]]; then
		echo "Cannot find all PLINK data files with prefix ${DATNAME}."
		exit
	fi
	plink --bfile $DATNAME --extract $TMP1 --make-bed --out .tmp_g1000_chr$CHR > /dev/null
	if [ ! -e .tmp_g1000_chr${CHR}.bed ]; then
		if [[ "$CHR" != "X" ]]; then
			echo "Error: no SNPs found in file $PVALFILE for chromosome $CHR"
			exit
		else
			echo "Warning: no SNPs found in file $PVALFILE for chromosome X"
		fi
	else
		if [[ "$CHR" != "1" ]]; then 
			echo ".tmp_g1000_chr${CHR}.bed .tmp_g1000_chr${CHR}.bim .tmp_g1000_chr${CHR}.fam" >> $TMP2; 
		fi
	fi
done

echo "Merging files..."
plink --bfile .tmp_g1000_chr1 --merge-list $TMP2 --make-bed --out $OUTNAME > /dev/null
rm .tmp_g1000_chr*


#create stat file
awk 	'NR==FNR 	{arr[$2]; next} 
	 $1 in arr	{print $0}'		 ${OUTNAME}.bim $TMP1 > $TMP2
echo "cluster stat" > ${OUTNAME}.stat
awk 	'NR==FNR 	{if ($2 > 0 && $2 <= 1) {logp[$1] = -log($2)/log(10)}; next} 
	 $1 in logp 	{stat[$3] += logp[$1]} 
	 END		{for (i in stat) {print i, stat[i]}}' $TMP2 $MAPFILE >> ${OUTNAME}.stat

#Put 50:50 case-control phenotype in .fam file
awk '{$6 = 1+(NR%2); print $0}' ${OUTNAME}.fam > $TMP2
mv $TMP2 ${OUTNAME}.fam

rm $TMP1


